/* Ogle - A video player
 * Remote Control
 * Copyright (C) 2004 Rossen Tchobanski <rosko@rosko.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <sys/msg.h>
#include <unistd.h>
#include <stdlib.h>

#include <ogle/dvdcontrol.h>
#include "actions.h"


#include <sys/socket.h>
#include <sys/un.h>
#include <errno.h>

#include <fcntl.h>

#define MAX_PID 65536

char *program_name;
int msgqid;

int bookmarks_autosave = 0;
int bookmarks_autoload = 0;


DVDNav_t *nav;
char *dvd_path;

int isPaused;
double speed;
ZoomMode_t zoom_mode;

void usage()
{
  fprintf(stderr, "Usage: %s [-v] [-h] [action]\n"  
                  "  run witout parameter -> List of actions\n", 
          program_name);
}

void version()
{
  fprintf(stderr, "%s version %s\n", 
          program_name, "0.0.0.1");
}

void cleanup()
{

}

int get_mid()
{
  static char cmdbuf[64];
  char buf[32];
  int fd;
  ssize_t count;
  int mid; 

  int pid;

  for (pid=1; pid<MAX_PID; pid++) { 
    sprintf(buf,"/proc/%u/cmdline",pid);
    if( (( fd=open(buf,O_RDONLY) )) == -1) continue;
    count = read(fd, cmdbuf, sizeof(cmdbuf)-1);
    close(fd);
    if(count<1) continue;
    cmdbuf[count] = '\0';

    if(!isprint(cmdbuf[0])) continue;
    while(count--) if(!isprint(cmdbuf[count])) cmdbuf[count]=' ';

    if (!memcmp(cmdbuf,"ogle_nav",8)) { 
      sscanf(cmdbuf, "ogle_nav -m %d", &mid);	
      return mid;
    }
  }

  return (-1);
}

void init()
{
  DVDResult_t res;
  int i;
  

  while((msgqid=get_mid())<0) i++;
  	  
//  fprintf(stdout,"ogle_ir was bind with msgqid %d\n",msgqid);

  if(msgqid !=-1) { // ignore sending data.
    sleep(1);
    res = DVDOpenNav(&nav, msgqid);
    init_actions(nav);
    if(res != DVD_E_Ok ) {
      DVDPerror("DVDOpen:", res);
      exit(1);
    }
  }
}


int main(int argc, char *argv[])
{
  int c,n;
  int ret;	
  char *action;
  char *code; 

  action_mapping_t *actions = get_action_mappings();

  program_name = argv[0];

  if (argc == 1) {
    printf("List of actions:\n");
    for(n = 0; actions[n].str != NULL; n++) {
      printf("  %s\n", actions[n].str);
    }
    printf("\n");
    return 0;
  }

  if (argc == 2) {
    if(!strcmp("-h", argv[1])) {
      usage();
      return 0; 
    }
    if(!strcmp("-v", argv[1])) {
      version();
      return 0; 
    }
  
  
    init();
    for(n = 0; actions[n].str != NULL; n++) {
      if(!strcmp(actions[n].str, argv[1])) {	
        if(actions[n].fun != NULL) {	       
          actions[n].fun(NULL); 	       
          printf("action %s done\n", actions[n].str); 
          return 0; // OK
        }				       
      }
    }
    return 1; // Action not found
  }

  return 2; // wrong numder of parameters
}
